powered by
Dayte
dtt_dayte(x, ...)# S3 method for Date dtt_dayte(x, start = 1L, ...)# S3 method for POSIXct dtt_dayte(x, start = 1L, ...)
# S3 method for Date dtt_dayte(x, start = 1L, ...)
# S3 method for POSIXct dtt_dayte(x, start = 1L, ...)
A Date vector with the year set to year.
A Date vector of the daytes.
A date/time vector.
Unused.
An integer scalar of the starting month or a Date scalar of the starting date.
Date: Dayte a Date vector
Date
POSIXct: Dayte a POSIXct vector
POSIXct
Other dayte: dtt_dayte_time(), dtt_daytt()
dtt_dayte_time()
dtt_daytt()
dtt_dayte(as.Date(c("2001-01-01", "2015-12-13")))
Run the code above in your browser using DataLab