powered by
Gets and sets month values for date/time vectors.
dtt_months(x, ...)dtt_months(x) <- valuedtt_month(x, ...)dtt_month(x) <- value# S3 method for Date dtt_month(x, ...)# S3 method for POSIXct dtt_month(x, ...)# S3 method for Date dtt_month(x) <- value# S3 method for POSIXct dtt_month(x) <- valuedtt_set_month(x, value)
dtt_months(x) <- value
dtt_month(x, ...)
dtt_month(x) <- value
# S3 method for Date dtt_month(x, ...)
# S3 method for POSIXct dtt_month(x, ...)
# S3 method for Date dtt_month(x) <- value
# S3 method for POSIXct dtt_month(x) <- value
dtt_set_month(x, value)
An integer vector (or the modified date/time vector).
A date/time vector.
Unused.
A integer vector of the month value(s).
Date: Get integer vector of month values for a Date vector
Date
POSIXct: Get integer vector of month values for a POSIXct vector
POSIXct
Date: Set month values for a Date vector
POSIXct: Set month values for a POSIXct vector
dtt_month_decimal()
Other set date: dtt_day(), dtt_years()
dtt_day()
dtt_years()
x <- as.Date("1990-01-02") dtt_month(x) dtt_month(x) <- 11L x x <- as.POSIXct("1990-01-02 23:40:51") dtt_month(x) dtt_month(x) <- 11L x
Run the code above in your browser using DataLab