Learn R Programming

dttr2 (version 0.4.0)

dtt_study_year: Study Year

Description

Study Year

Usage

dtt_study_year(x, start = 1L, full = TRUE)

Value

A character vector of the study year or an integer vector of the first year.

Arguments

x

A Date or POSIXct vector.

start

An integer vector of the starting month or a Date vector of the starting date.

full

A flag specifying whether to return a character vector of the study years (or an integer vector of the first year)

Examples

Run this code
dtt_study_year(as.Date(c("2000-03-31", "2000-04-01", "2001-04-01")), start = 4L)
dtt_study_year(as.Date(c("2000-03-31", "2000-04-01", "2001-04-01")), start = 4L, full = FALSE)

Run the code above in your browser using DataLab